#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""
Solicitor: uses metadata.json to determine delivery locations
"""
import json
from typing import Dict


class Solicitor:
    def __init__(self, filename: str):
        self.filename = filename

    def solicit_delivery_location(self) -> str:
        """
        Grab destination dir from metadata.json

        :return:
        """
        with open(self.filename) as file:
            metadata = json.loads(file.read())
            return metadata["destinationDirectory"]

    def solicit_request_params(self) -> Dict:
        """
        Grab request ID and fileset ID(s) from metadata.json

        :return:
        """
        params = {}
        with open(self.filename) as file:
            metadata = json.loads(file.read())
            # this will be workflow request ID
            params["system_id"] = int(metadata["systemId"])
            # this will be one or more SDM IDs
            # (also known as fileset ID, external_name,
            # because if one name is good then three must be thrice as good)
            params["sdm_ids"] = metadata["fileSetIds"]
            params["workflow"] = metadata["workflowName"]

        return params
