#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
# Metrics make the world go round.
# Yes, this is a reference to Hitchhikers Guide to the Galaxy.

"""
scripted access to the metrics database views for data analysts
"""

import argparse
import logging
import sys

from pycapo import CapoConfig

from ws_metrics.connections import MDDBConnector
from ws_metrics.inquisition import LifeUniverseEverything

logger = logging.getLogger("ws_metrics")
logger.setLevel(logging.INFO)
logger.addHandler(logging.StreamHandler(sys.stdout))


def parser() -> argparse.ArgumentParser:
    """
    Initialize argument parser for command-line arguments

    :return: Argument parser
    """
    parser = argparse.ArgumentParser(
        description="Workspaces metrics reporter", formatter_class=argparse.RawTextHelpFormatter
    )
    parser.add_argument(
        "-c",
        "--capability",
        nargs=1,
        action="store",
        required=False,
        help="report number of times a capability has executed",
    )
    parser.add_argument(
        "-b",
        "--between",
        nargs=3,
        action="store",
        required=False,
        help="report the number of times a capability has executed between two user provided timestamps.",
    )
    parser.add_argument(
        "-rd",
        "--requestdatasize",
        nargs=1,
        action="store",
        required=False,
        help="reports the volume of data downloaded for this request in kilobytes.",
    )
    parser.add_argument(
        "-d",
        "--datasize",
        nargs=2,
        action="store",
        required=False,
        help="reports the total volume of data downloaded via the workspaces system over a specified period of time.",
    )

    return parser


def _get_capo_settings():
    return CapoConfig().settings("metadataDatabase")


def main():
    print("**********************************")
    print("* WELCOME TO WORKSPACES METRICS! *")
    print("**********************************")
    args = parser().parse_args()

    conn = MDDBConnector()

    LifeUniverseEverything(conn, args).run_metrics(args)
    conn.close()
