"""Generic Report operations for metrics reporting"""
from typing import Dict

import pendulum

from ws_metrics.enums import ReportEnum
from ws_metrics.schema import AbstractTextFile


class Report:
    """Base class for report generation"""

    def __init__(self, report: ReportEnum):
        self.type = report.title
        self.template = report.template_type
        self.name = self.set_report_title(report)

    @staticmethod
    def set_report_title(report: ReportEnum) -> str:
        """
        Use the report type to determine the report title

        :param report: The report type to generate
        :return: the title of the report
        """
        timestamp = pendulum.now().format("YYYY_MM_DDThh_mm_ss")

        return f"{report.title}_{timestamp}.txt"

    def render_report_template(self, data: Dict) -> AbstractTextFile:
        pass
